@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2013 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2013 Balabit
  * Copyright (c) 1998-2013 Balázs Scheidler
  *
  * This library is free software; you can redistribute it and/or
@@ -27,9 +27,16 @@
 #include "syslog-ng.h"
 #include "thread-utils.h"
 
+typedef struct _MainLoop MainLoop;
+
+typedef struct _MainLoopOptions
+{
+  gchar *preprocess_into;
+  gboolean syntax_only;
+  gboolean interactive_mode;
+  gboolean server_mode;
+} MainLoopOptions;
 
-extern gboolean syntax_only;
-extern gboolean __main_loop_is_terminating;
 extern ThreadId main_thread_handle;
 
 typedef gpointer (*MainLoopTaskFunc)(gpointer user_data);
@@ -37,7 +44,7 @@ typedef gpointer (*MainLoopTaskFunc)(gpointer user_data);
 static inline void
 main_loop_assert_main_thread(void)
 {
-#if ENABLE_DEBUG
+#if SYSLOG_NG_ENABLE_DEBUG
   g_assert(threads_equal(main_thread_handle, get_thread_id()));
 #endif
 }
@@ -48,23 +55,19 @@ main_loop_is_main_thread(void)
   return threads_equal(main_thread_handle, get_thread_id());
 }
 
-static inline gboolean
-main_loop_is_terminating(void)
-{
-  return __main_loop_is_terminating;
-}
+void main_loop_reload_config(MainLoop *self);
+void main_loop_exit(MainLoop *self);
 
-void main_loop_reload_config(void);
-void main_loop_exit(void);
+int main_loop_read_and_init_config(MainLoop *self);
+void main_loop_run(MainLoop *self);
 
-int main_loop_read_and_init_config(void);
-void main_loop_run(void);
-
-void main_loop_init(void);
-void main_loop_deinit(void);
+MainLoop *main_loop_get_instance(void);
+void main_loop_init(MainLoop *self, MainLoopOptions *options);
+void main_loop_deinit(MainLoop *self);
 
 void main_loop_add_options(GOptionContext *ctx);
-void main_loop_global_init(void);
+gboolean main_loop_is_server_mode(MainLoop *self);
+void main_loop_set_server_mode(MainLoop *self, gboolean server_mode);
 
 gboolean main_loop_initialize_state(GlobalConfig *cfg, const gchar *persist_filename);
 
