@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2012 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2012 Balabit
  * Copyright (c) 1998-2012 Balázs Scheidler
  *
  * This library is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@ extern int log_stderr;
 typedef void (*MsgPostFunc)(LogMessage *msg);
 
 void msg_set_context(LogMessage *msg);
-EVTREC *msg_event_create(gint prio, const char *desc, EVTTAG *tag1, ...);
+EVTREC *msg_event_create(gint prio, const char *desc, EVTTAG *tag1, ...) __attribute__((nonnull(2)));
 EVTREC *msg_event_create_from_desc(gint prio, const char *desc);
 void msg_event_free(EVTREC *e);
 void msg_event_send(EVTREC *e);
@@ -52,15 +52,15 @@ void msg_add_option_group(GOptionContext *ctx);
 
 /* fatal->warning goes out to the console during startup, notice and below
  * comes goes to the log even during startup */
-#define msg_fatal(desc, tag1, tags...)    msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_CRIT, desc, tag1, ##tags ))
-#define msg_error(desc, tag1, tags...)    msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_ERR, desc, tag1, ##tags ))
-#define msg_warning(desc, tag1, tags...)  msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_WARNING, desc, tag1, ##tags ))
-#define msg_notice(desc, tag1, tags...)   msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_NOTICE, desc, tag1, ##tags ))
-#define msg_info(desc, tag1, tags...)     msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_INFO, desc, tag1, ##tags ))
+#define msg_fatal(desc, tags...)    msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_CRIT, desc, ##tags, NULL ))
+#define msg_error(desc, tags...)    msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_ERR, desc, ##tags, NULL ))
+#define msg_warning(desc, tags...)  msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_WARNING, desc, ##tags, NULL ))
+#define msg_notice(desc, tags...)   msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_NOTICE, desc, ##tags, NULL ))
+#define msg_info(desc, tags...)     msg_event_suppress_recursions_and_send(msg_event_create(EVT_PRI_INFO, desc, ##tags, NULL ))
 
 /* just like msg_info, but prepends the message with a timestamp -- useful in interactive
  * tools with long running time to provide some feedback */
-#define msg_progress(desc, tag1, tags...) 					  \
+#define msg_progress(desc, tags...) 					  \
         do { 									  \
           time_t t;								  \
           char *timestamp, *newdesc; 						  \
@@ -69,32 +69,32 @@ void msg_add_option_group(GOptionContext *ctx);
           timestamp = ctime(&t); 						  \
           timestamp[strlen(timestamp) - 1] = 0; 				  \
           newdesc = g_strdup_printf("[%s] %s", timestamp, desc); 		  \
-          msg_event_send(msg_event_create(EVT_PRI_INFO, newdesc, tag1, ##tags )); \
+          msg_event_send(msg_event_create(EVT_PRI_INFO, newdesc, ##tags, NULL )); \
           g_free(newdesc); 							  \
         } while (0)
 
-#define msg_verbose(desc, tag1, tags...)                                          \
+#define msg_verbose(desc, tags...)                                          \
 	do {                                                                      \
 	  if (G_UNLIKELY(verbose_flag))                                           \
-	    msg_info(desc, tag1, ##tags );                                        \
+	    msg_info(desc, ##tags );                                        \
 	} while (0)
 
-#define msg_debug(desc, tag1, tags...) 						  \
+#define msg_debug(desc, tags...) 						  \
 	do { 									  \
 	  if (G_UNLIKELY(debug_flag))                                             \
 	    msg_event_suppress_recursions_and_send(                               \
-	          msg_event_create(EVT_PRI_DEBUG, desc, tag1, ##tags ));          \
+	          msg_event_create(EVT_PRI_DEBUG, desc, ##tags, NULL ));          \
 	} while (0)
 
-#if ENABLE_DEBUG
-#define msg_trace(desc, tag1, tags...) 						  \
+#if SYSLOG_NG_ENABLE_DEBUG
+#define msg_trace(desc, tags...) 						  \
 	do { 									  \
 	  if (G_UNLIKELY(trace_flag))            				  \
             msg_event_suppress_recursions_and_send(                               \
-                  msg_event_create(EVT_PRI_DEBUG, desc, tag1, ##tags ));          \
+                  msg_event_create(EVT_PRI_DEBUG, desc, ##tags, NULL ));          \
 	} while (0)
 #else
-#define msg_trace(desc, tag1, tags...)
+#define msg_trace(desc, tags...)
 #endif
 
 #define __once()					\
